'use strict';

exports.__esModule = true;
exports.getUserBestRankWorldwide = exports.getRankForLanguage = exports.getTopUsers = exports.getUser = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _ramda = require('ramda');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var instance = _axios2.default.create({
  baseURL: 'http://git-awards.com/api/v0',
  responseType: 'json'
});

var returnData = (0, _ramda.prop)('data');
var rankings = (0, _ramda.lensProp)('rankings');
var transformUser = (0, _ramda.compose)(function (user) {
  return (0, _ramda.set)(rankings, (0, _ramda.map)(_utils.camelCaseKeys, (0, _ramda.view)(rankings, user), user), user);
}, _utils.camelCaseKeys);

/**
 * Return a specific user's rankings by username
 */
var getUser = exports.getUser = function getUser(username) {
  return instance.get('/users/' + username).then((0, _ramda.compose)(transformUser, (0, _ramda.prop)('user'), returnData));
};

/**
 * Return the top users
 */
var getTopUsers = exports.getTopUsers = function getTopUsers() {
  return instance.get('/users').then(returnData).then((0, _ramda.prop)('users'));
};

/**
 * Returns a ranking for a specified language
 */
var getRankForLanguage = exports.getRankForLanguage = function getRankForLanguage(language, user) {
  return (0, _ramda.find)((0, _ramda.propEq)('language', language), user.rankings);
};

var sortByProp = (0, _ramda.curry)(function (propName, xs) {
  return (0, _ramda.sortBy)((0, _ramda.prop)(propName), xs);
});

/**
 * Get the best ranked language for a given user
 */
var getUserBestRankWorldwide = exports.getUserBestRankWorldwide = (0, _ramda.memoize)(function (user) {
  return (0, _ramda.head)(sortByProp('worldRank', user.rankings));
});